@@ -1360,6 +1360,7 @@ class ShareActionsTest(test.TestCase):
 
         self.mock_object(share_api.API, "deny_access", _stub_deny_access)
         self.mock_object(share_api.API, "access_get", _fake_access_get)
+        self.mock_object(self.controller, '_check_for_access_rule_locks')
 
         id = 'fake_share_id'
         body = {"os-deny_access": {"access_id": 'fake_acces_id'}}
@@ -1377,14 +1378,20 @@ class ShareActionsTest(test.TestCase):
         share_network = db_utils.create_share_network()
         share = db_utils.create_share(share_network_id=share_network['id'])
         self.mock_object(share_api.API, 'get', mock.Mock(return_value=share))
+        self.mock_object(self.controller, '_check_for_access_rule_locks')
 
         id = 'fake_share_id'
-        body = {"os-deny_access": {"access_id": 'fake_acces_id'}}
+        access_data = {"access_id": 'fake_acces_id'}
+        body = {"os-deny_access": access_data}
         req = fakes.HTTPRequest.blank('/v1/tenant1/shares/%s/action' % id)
 
         res = self.controller._deny_access(req, id, body)
 
         self.assertEqual(202, res.status_int)
+        self.controller._check_for_access_rule_locks.assert_called_once_with(
+            req.environ['manila.context'], access_data,
+            access_data['access_id'], id
+        )
         self.mock_policy_check.assert_called_once_with(
             req.environ['manila.context'], 'share', 'deny_access')
 
@@ -1394,6 +1401,7 @@ class ShareActionsTest(test.TestCase):
 
         self.mock_object(share_api.API, "deny_access", _stub_deny_access)
         self.mock_object(share_api.API, "access_get", _fake_access_get)
+        self.mock_object(self.controller, '_check_for_access_rule_locks')
 
         id = 'super_fake_share_id'
         body = {"os-deny_access": {"access_id": 'fake_acces_id'}}
@@ -1441,12 +1449,14 @@ class ShareActionsTest(test.TestCase):
         access_id = 'fake_access_id'
         share_id = 'fake_share_id'
 
+        self.mock_object(context, 'elevated', mock.Mock(return_value=context))
         self.controller._check_for_access_rule_locks(
             context, {}, access_id, share_id)
 
         delete_search_opts = {
             'resource_id': access_id,
-            'resource_action': constants.RESOURCE_ACTION_DELETE
+            'resource_action': constants.RESOURCE_ACTION_DELETE,
+            'all_projects': True,
         }
 
         resource_locks.API.get_all.assert_called_once_with(
@@ -1465,6 +1475,7 @@ class ShareActionsTest(test.TestCase):
         access_id = 'fake_access_id'
         share_id = 'fake_share_id'
 
+        self.mock_object(context, 'elevated', mock.Mock(return_value=context))
         self.assertRaises(
             webob.exc.HTTPForbidden,
             self.controller._check_for_access_rule_locks,
@@ -1472,7 +1483,8 @@ class ShareActionsTest(test.TestCase):
 
         delete_search_opts = {
             'resource_id': access_id,
-            'resource_action': constants.RESOURCE_ACTION_DELETE
+            'resource_action': constants.RESOURCE_ACTION_DELETE,
+            'all_projects': True,
         }
 
         resource_locks.API.get_all.assert_called_once_with(
@@ -1497,6 +1509,7 @@ class ShareActionsTest(test.TestCase):
         access_id = 'fake_access_id'
         share_id = 'fake_share_id'
 
+        self.mock_object(context, 'elevated', mock.Mock(return_value=context))
         self.assertRaises(
             webob.exc.HTTPForbidden,
             self.controller._check_for_access_rule_locks,
@@ -1504,7 +1517,8 @@ class ShareActionsTest(test.TestCase):
 
         delete_search_opts = {
             'resource_id': access_id,
-            'resource_action': constants.RESOURCE_ACTION_DELETE
+            'resource_action': constants.RESOURCE_ACTION_DELETE,
+            'all_projects': True,
         }
 
         resource_locks.API.get_all.assert_called_once_with(
@@ -1535,6 +1549,7 @@ class ShareActionsTest(test.TestCase):
         access_id = 'fake_access_id'
         share_id = 'fake_share_id'
 
+        self.mock_object(context, 'elevated', mock.Mock(return_value=context))
         self.assertRaises(
             webob.exc.HTTPForbidden,
             self.controller._check_for_access_rule_locks,
@@ -1542,7 +1557,8 @@ class ShareActionsTest(test.TestCase):
         )
         delete_search_opts = {
             'resource_id': access_id,
-            'resource_action': constants.RESOURCE_ACTION_DELETE
+            'resource_action': constants.RESOURCE_ACTION_DELETE,
+            'all_projects': True,
         }
         resource_locks.API.get_all.assert_called_once_with(
             context, search_opts=delete_search_opts, show_count=True
@@ -1569,15 +1585,19 @@ class ShareActionsTest(test.TestCase):
         access_id = 'fake_access_id'
         share_id = 'fake_share_id'
 
+        self.mock_object(context, 'elevated', mock.Mock(return_value=context))
         self.controller._check_for_access_rule_locks(
             context, {'unrestrict': True}, access_id, share_id)
 
         delete_search_opts = {
             'resource_id': access_id,
-            'resource_action': constants.RESOURCE_ACTION_DELETE
+            'resource_action': constants.RESOURCE_ACTION_DELETE,
+            'all_projects': True,
         }
         resource_locks.API.get_all.assert_called_once_with(
-            context, search_opts=delete_search_opts, show_count=True)
+            context.elevated(), search_opts=delete_search_opts,
+            show_count=True
+        )
         (resource_locks.API.ensure_context_can_delete_lock
             .assert_called_once_with(
                 context, locks[0]['id']))
